@@ -5,6 +5,7 @@ import time
 import requests
 from airflow.operators.python import PythonOperator
 from datetime import datetime
+import json
 
 DIEGO_MAX_ROWS = 10000000
 log = logging.getLogger(__name__)
@@ -12,7 +13,7 @@ log = logging.getLogger(__name__)
 
 class DiegoOperator(PythonOperator):
     def __init__(self, task_id, cube_id, platform_url: str, python_callable, op_kwargs=None, ignore_empty_dataframe=False, sleep_between_chunks=30,
-                 diego_chunksize=DIEGO_MAX_ROWS, date_columns: list = None, pandas_kwargs: dict = None, retries=2,full_load="false", **kwargs) -> None:
+                 diego_chunksize=DIEGO_MAX_ROWS, date_columns: list = None, pandas_kwargs: dict = None, retries=2,full_load=False, **kwargs) -> None:
         """
         Operator that expects a python_callable that returns or yields a pandas Dataframe to process and insert the corresponding Dataframe into a csv to Diego
 
@@ -26,7 +27,7 @@ class DiegoOperator(PythonOperator):
         :param sleep_between_chunks: number in seconds to wait before sending another chunk of dataframe to Diego
         :param diego_chunksize: max number of rows per chunk to send to Diego
         :param date_columns: list of columns containing the name of the columns that are date type to be pre-processed (SID have specific requirements for date types)
-        :param full_load: wheter or not the destiny cube will have its data erased before inserting new data. Values "true" or "false" (default)
+        :param full_load: wheter or not the destiny cube will have its data erased before inserting new data. Values True or False (default)
         :param pandas_kwargs: dictionary containing the parameters to be forwarded to pandas 'to_parquet' method
         :param kwargs: all kwargs will be forwarded to the PythonOperator as parameters
         """
@@ -49,22 +50,24 @@ class DiegoOperator(PythonOperator):
         self.full_load = full_load
 
     def send_file_path_to_diego(self, file_path):
-        data_format = {
+        data_format = json.dumps({
             "destinationId": self.cube_id,
             "file": file_path,
-            "pattern": ".*.parquet",
+            "pattern": ".*part.*",
             "fullLoad": self.full_load
-            }
+            })
 
         endpoint = f"{self.platform_url}/controller/dataloader/cube-load/s3"
+        headers = {'Content-Type': 'application/json'}
 
         response = requests.post(
             endpoint,
             data=data_format,
+            headers=headers
         )
 
         print(f"File sent to Diego to path {file_path}")
-        print(f"Diego response {response}")
+        print(f"Diego response {response.text}")
 
         return response
 
